@@ -7,23 +7,16 @@ auxm_send_cmd(
     int	    len,
     char*   data);
 
-extern int
-auxm_serial_dump(
-    void);
+extern int auxm_serial_dump(void);
 
-extern int
-auxm_init();
+extern int machine_has_auxm(void);
+extern int auxm_init(void);
 
-extern void
-auxm_serial_check(
-    void);
+extern void auxm_serial_check(void);
 
-extern void
-check_3800_func_buttons(
-    void);
+extern void check_3800_func_buttons(void);
 
-extern void
-auxm_fini_serial();
+extern void auxm_fini_serial(void);
 
 extern void hilite_button(int which);
 
@@ -32,4 +25,7 @@ extern void exec_button(int which);
 extern void set_last_buttonpress(char which);
 extern int get_last_buttonpress(void);
 
+extern void set_exec_buttons_automatically(char c);
+extern char get_exec_buttons_automatically(void);
+
 #endif
